summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2020-10-22 10:42:19 +0200
committerGitHub <noreply@github.com>2020-10-22 10:42:19 +0200
commit886935f09b885b90391c29d1be85d286af15222c (patch)
treedf498a0607290449cf588b8fe7ab2a3d034a5331
parentc4559d9048a3f386528984d8f5d96259642a6a2b (diff)
parent17c1db72fef43b50d4454ed4bb6df1a85781501f (diff)
downloadATCD-886935f09b885b90391c29d1be85d286af15222c.tar.gz
Merge pull request #1262 from jwillemsen/jwi-guidelines
Fixed some typos and removed some references/support for subversion as version control
-rw-r--r--ACE/bin/PerlACE/Run_Test.pm2
-rw-r--r--ACE/bin/PerlACE/TestTarget.pm6
-rwxr-xr-xACE/bin/doxygen-convert-h.pl18
-rwxr-xr-xACE/bin/fuzz.pl71
-rw-r--r--ACE/docs/ACE-guidelines.html15
5 files changed, 19 insertions, 93 deletions
diff --git a/ACE/bin/PerlACE/Run_Test.pm b/ACE/bin/PerlACE/Run_Test.pm
index a562846cb93..124fd111a0e 100644
--- a/ACE/bin/PerlACE/Run_Test.pm
+++ b/ACE/bin/PerlACE/Run_Test.pm
@@ -1,6 +1,6 @@
#!/usr/bin/env perl
-# This module contains a few miscellanous functions and some
+# This module contains a few miscellaneous functions and some
# startup ARGV processing that is used by all tests.
use PerlACE::Process;
diff --git a/ACE/bin/PerlACE/TestTarget.pm b/ACE/bin/PerlACE/TestTarget.pm
index 4b310f3b55c..347c6cf3a2f 100644
--- a/ACE/bin/PerlACE/TestTarget.pm
+++ b/ACE/bin/PerlACE/TestTarget.pm
@@ -142,7 +142,7 @@ sub GetConfigSettings ($)
$self->{tao_root} = $ENV{'TAO_ROOT'};
}
} else {
- # fall back to assuming classic hierarchical struture
+ # fall back to assuming classic hierarchical structure
$self->{tao_root} = "$self->{ace_root}/TAO";
}
$env_name = $env_prefix.'CIAO_ROOT';
@@ -162,7 +162,7 @@ sub GetConfigSettings ($)
$self->{ciao_root} = $ENV{'CIAO_ROOT'};
}
} else {
- # fall back to assuming classic hierarchical struture
+ # fall back to assuming classic hierarchical structure
$self->{ciao_root} = "$self->{tao_root}/CIAO";
}
@@ -183,7 +183,7 @@ sub GetConfigSettings ($)
$self->{dance_root} = $ENV{'DANCE_ROOT'};
}
} else {
- # fall back to assuming classic hierarchical struture
+ # fall back to assuming classic hierarchical structure
$self->{dance_root} = "$self->{tao_root}/DAnCE";
}
diff --git a/ACE/bin/doxygen-convert-h.pl b/ACE/bin/doxygen-convert-h.pl
index b8104f39f22..253e351e1a2 100755
--- a/ACE/bin/doxygen-convert-h.pl
+++ b/ACE/bin/doxygen-convert-h.pl
@@ -41,16 +41,14 @@ sub recursive_find {
if (opendir($fh, $file)) {
foreach my $f (grep(!/^\.\.?$/, readdir($fh))) {
- if ($f ne '.svn') {
- my($full) = "$file/$f";
- if (-d $full) {
- push(@rfiles, recursive_find($full));
- }
- else {
- push(@rfiles, $full)
- if ($f =~ /\.(h|hxx|hpp|hh|inl|idl|cpp|cxx|cc|c|C)$/)
- ;
- }
+ my($full) = "$file/$f";
+ if (-d $full) {
+ push(@rfiles, recursive_find($full));
+ }
+ else {
+ push(@rfiles, $full)
+ if ($f =~ /\.(h|hxx|hpp|hh|inl|idl|cpp|cxx|cc|c|C)$/)
+ ;
}
}
closedir($fh);
diff --git a/ACE/docs/ACE-guidelines.html b/ACE/docs/ACE-guidelines.html
index d95affef956..26d1b6062c2 100644
--- a/ACE/docs/ACE-guidelines.html
+++ b/ACE/docs/ACE-guidelines.html
@@ -181,21 +181,6 @@ rather than
should consist of complete sentences, <em>i.e.</em>, start
with a capital letter and end with a period.<p>
- <li>Insert a svn keyword string at the top of every source file,
- Makefile, config file, <em>etc</em>. For C++ files, it is:
- <pre>
- // $<!-- -->Id$
- </pre>
- It is not necessary to fill in the fields of the keyword string,
- or modify them when you edit a file that already has one. SVN
- does that automatically when you checkout or update the file.<p>
-
- To insert that string at the top of a file:
- <pre>
- perl -pi -e \
- 'if (! $o) {printf "// \$<!-- -->Id\$\n\n";}; $o = 1;' <em>file</em>
- </pre><p>
-
<li>Be sure to follow the guidelines and restrictions for use of the
documentation tools for ACE
header files, which must follow the
diff --git a/ACE/bin/fuzz.pl b/ACE/bin/fuzz.pl
index cbe752d84a6..7cadf939bf1 100755
--- a/ACE/bin/fuzz.pl
+++ b/ACE/bin/fuzz.pl
@@ -68,25 +68,6 @@ $warnings = 0;
##############################################################################
-# Use 'svn -q st' to get a list of locally modified
-# files to look through
-sub find_mod_svn_files ()
-{
- unless (open (SVN, "svn -q st |")) {
- print STDERR "Error: Could not run svn\n";
- return 0;
- }
-
- while (<SVN>) {
- # 1234567 (see "svn help st" for column definitions)
- if (/^[MA].....\s+(.*)$/) {
- store_file ($1);
- }
- }
- close (SVN);
- return 1;
-}
-
# Use 'git status -s' to get a list of locally modified
# files to look through
sub find_mod_git_files ()
@@ -107,8 +88,8 @@ sub find_mod_git_files ()
sub find_mod_files ()
{
- if (!(find_mod_svn_files() && find_mod_git_files())) {
- print "Could use neither svn nor git to find modified files\n";
+ if (!find_mod_git_files()) {
+ print "Could use git to find modified files\n";
exit (1);
}
}
@@ -415,14 +396,14 @@ sub check_for_newline ()
}
# This test checks for files that are not allowed to be in svn
sub check_for_noncvs_files ()
{
return if is_suppressed ();
- print "Running non svn files check\n";
+ print "Running non versioned controlled files check\n";
foreach $file (@files_noncvs, @files_dsp, @files_dsw, @files_makefile, @files_bor) {
- print_error ("File $file should not be in svn!");
+ print_error ("File $file should not be in version control!");
}
}
@@ -1357,7 +1338,7 @@ sub check_for_dependency_file ()
$depend = $path . $depend;
unless (open (DFILE, $depend)) {
print_error ("DEPENDENCY_FILE \"$depend\" not found");
- print " Either add \"$depend\" to svn ";
+ print " Either add \"$depend\" to git ";
print "or remove DEPENDENCY_FILE variable\n";
print " from $file\n\n";
}
@@ -1891,42 +1872,6 @@ sub check_for_bad_ace_trace()
}
}
-
-# This test checks for broken ChangeLog entries.
-sub check_for_changelog_errors ()
-{
- return if is_suppressed ();
-
- print "Running ChangeLog check\n";
- foreach $file (@files_changelog) {
- if (open (FILE, $file)) {
- my $found_backslash = 0;
- my $found_cvs_conflict = 0;
-
- print "Looking at file $file\n" if $opt_d;
- while (<FILE>) {
-
- next if m/^\s*\/\//;
- next if m/^\s*$/;
-
- # Check for backslashes in paths.
- if (m/\*.*\\[^ ]*:/) {
- print_error ("$file:$.: Backslashes in file path");
- }
-
- # Check for svn conflict tags
- if (m/^<<<<</ || m/^=====/ || m/^>>>>>/) {
- print_error ("$file:$.: svn conflict markers");
- }
- }
- close (FILE);
- }
- else {
- print STDERR "Error: Could not open $file\n";
- }
- }
-}
-
sub check_for_deprecated_macros ()
{
return if is_suppressed ();
@@ -2413,7 +2358,7 @@ if (!getopts ('cdx:hl:t:s:mv') || $opt_h) {
" this will disable the run level setting\n";
print " -s test_names specify comma-separated list of tests to suppress\n".
" this will supplement the run level setting\n";
- print " -m only check locally modified files (uses svn)\n";
+ print " -m only check locally modified files (uses git)\n";
print "======================================================\n";
print "list of the tests that could be run or suppressed:\n";
print <<EOT;
@@ -2445,7 +2390,6 @@ if (!getopts ('cdx:hl:t:s:mv') || $opt_h) {
check_for_bad_run_test
check_for_absolute_ace_wrappers
check_for_bad_ace_trace
- check_for_changelog_errors
check_for_ptr_arith_t
check_for_include (disabled by default)
check_for_non_bool_operators
@@ -2540,7 +2484,6 @@ check_for_versioned_namespace_begin_end () if ($opt_l >= 4);
check_for_mismatched_filename () if ($opt_l >= 2);
check_for_absolute_ace_wrappers () if ($opt_l >= 3);
check_for_bad_ace_trace () if ($opt_l >= 4);
-check_for_changelog_errors () if ($opt_l >= 4);
check_for_ptr_arith_t () if ($opt_l >= 4);
check_for_non_bool_operators () if ($opt_l > 2);
check_for_long_file_names () if ($opt_l >= 1);
@@ -415,14 +396,14 @@ sub check_for_newline ()
}
-# This test checks for files that are not allowed to be in svn
+# This test checks for files that are not allowed to be in version control
sub check_for_noncvs_files ()
{